"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateUpdateJobBaseParameters = void 0;
const parameters_1 = require("../../parameters");
const exception_1 = require("../../exception");
class CreateUpdateJobBaseParameters extends parameters_1.BaseParameters {
    setName(jobName) {
        if (jobName.length >= 170) {
            throw new exception_1.SmartlingException("Job name should be less than 170 characters.");
        }
        this.set("jobName", jobName);
        return this;
    }
    setDescription(description) {
        if (description && (description.length >= 2000)) {
            throw new exception_1.SmartlingException("Job description should be less than 2000 characters.");
        }
        this.set("description", description);
        return this;
    }
    setDueDate(dueDate) {
        this.set("dueDate", dueDate ? dueDate.toISOString() : null);
        return this;
    }
    setReferenceNumber(referenceNumber) {
        this.set("referenceNumber", referenceNumber);
        return this;
    }
    setCallbackUrl(callbackUrl) {
        if (callbackUrl && (callbackUrl.length > 8192)) {
            throw new exception_1.SmartlingException("Job callback URL should be not greater than 8192 characters.");
        }
        this.set("callbackUrl", callbackUrl);
        return this;
    }
    setCallbackMethod(callbackMethod) {
        this.set("callbackMethod", callbackMethod);
        return this;
    }
    setCustomFields(customFields) {
        this.set("customFields", customFields);
        return this;
    }
}
exports.CreateUpdateJobBaseParameters = CreateUpdateJobBaseParameters;
//# sourceMappingURL=create-update-job-base-parameters.js.map